@@ -22,13 +22,13 @@ use SQL::Entity ':all';
 
 %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-$VERSION = 0.01;
+$VERSION = 0.02;
 
 =head1 NAME
 
-Persistence::Entity - Entity persistence abstraction layer.
+Persistence::Entity - Persistence API for perl classes.
 
-=cut  
+=cut
 
 =head1 CLASS HIERARCHY
 
@@ -92,15 +92,17 @@ Defines tigger that will execute on one of the following event
 before_insert after_insert before_update after_update before_delete after_delete, on_fetch
 Takes event name as first parameter, and callback as secound parameter.
 
-$entity->trigger(before_insert => sub {
-    my ($self) = @_;
-    #do stuff
-});
+
+    $entity->trigger(before_insert => sub {
+        my ($self) = @_;
+        #do stuff
+    });
+
 
 =cut
 
 {
-    
+
     has '%.triggers' => (
         transistent   => 1,
         item_accessor => 'trigger',
@@ -168,58 +170,27 @@ has '%.dml_filter_values';
 
 =over
 
-=item run_event
-
-=cut
-
-sub run_event {
-    my ($self, $name, @args) = @_;
-    my $event = $self->trigger($name);
-    $event->(@args) if $event;
-}
-
-
-=item validate_trigger
-
-Validates triggers types
-
-=cut
-
-{
-    my @triggers = qw(before_insert after_insert before_update after_update before_delete after_delete on_fetch);
-    sub validate_trigger {
-        my ($self, $name, $value) = @_;
-        confess "invalid trigger name: $name , must be one of " . join(",", @triggers)
-            unless (grep {$name eq $_} @triggers);
-        confess "secound parameter must be a callback"
-            unless ref($value) eq 'CODE';
-    }
-}
-
-
 =item find
 
-Returns list of objects or resultsets for passed in entity that meets passed in condition
-Takes entity name, class name to which resultset will be casted,
-(if class name is undef then hash ref will be return instead), list of names parameters that will
-be used as condition or condition object.  If class name has the ORM mapping, then name parameters
-must be objects' attributs . Condition object always should use entity column.
+Returns list of objects or resultsets.
+Takes class name to which resultset will be casted, (if class name is undef then hash ref will be return instead),
+list of names parameters that will be used as condition or condition object.
+Condition object always should use entity column.
 
 
     my $entity = $entity_manager->entity('emp');
-
     my ($emp) = $entity->find('Employee', ename => 'adrian');
     or
-
     my @emp = $entity->find('Employee', sql_cond('ename', 'LIKE', 'a%'));
     #array of Employee objects.
 
+
 =cut
 
 sub find {
     my ($self, $class_name, @args) = (@_);
     my $entity_manager = $self->entity_manager;
-    my $condition = $entity_manager->_condition_converter($class_name, @args, $self->filter_condition_values);
+    my $condition = $entity_manager->condition_converter($class_name, @args, $self->filter_condition_values);
     my ($sql, $bind_variables) = $self->query(undef, $condition);
     $self->_execute_query($sql, $bind_variables, $class_name);
 }
@@ -227,27 +198,26 @@ sub find {
 
 =item search
 
-Returns list of objects or resultsets for passed in entity that meets passed in condition
-Takes entity name, class name to which resultset will be casted,
-(if class name is undef then hash ref will be return instead), list of names parameters that will
-be used as condition or condition object.  If class name has the ORM mapping, then name parameters
-must be objects' attributs . Condition object always should use entity column.
+Returns list of objects or resultsets.
+Takes array ref of requested column to projection, class name to which resultset will be casted,
+(if class name is undef then hash ref will be return instead),
+list of names parameters that will be used as condition or condition object.
+Condition object always should use entity column.
 
 
     my $entity = $entity_manager->entity('emp');
-
     my ($emp) = $entity->find('Employee', ename => 'adrian');
     or
-
     my @emp = $entity->find('Employee', sql_cond('ename', 'LIKE', 'a%'));
     #array of Employee objects.
 
+
 =cut
 
 sub search {
     my ($self, $requested_columns, $class_name,  @args) = @_;
     my $entity_manager = $self->entity_manager;
-    my $condition = $entity_manager->_condition_converter($class_name, @args, $self->filter_condition_values);
+    my $condition = $entity_manager->condition_converter($class_name, @args, $self->filter_condition_values);
     my ($sql, $bind_variables) = $self->query($requested_columns, $condition);
     $self->_execute_query($sql, $bind_variables, $class_name);
 }
@@ -255,31 +225,29 @@ sub search {
 
 =item lock
 
-Returns and locks list and of objects or resultsets for passed in entity that meets passed in condition
-Takes entity name, class name to which resultset will be casted,
-(if class name is undef then hash ref will be return instead), list of names parameters that will
-be used as condition or condition object.  If class name has the ORM mapping, then name parameters
-must be objects' attributs . Condition object always should use entity column.
+Returns and locks list and of objects or resultsets.
+Takes entity name, class name to which resultset will be casted, (if class name is undef then hash ref will be return instead),
+list of names parameters that will be used as condition or condition object.
+Condition object always should use entity column.
 Locking is forced by SELECT ... FOR UPDATE clause
 
-    my $entity = $entity_manager->entity('emp');
 
+    my $entity = $entity_manager->entity('emp');
     my ($emp) = $entity->lock('Employee', ename => 'adrian');
     or
-
     my @emp = $entity->lock('Employee', sql_cond('ename', 'LIKE', 'a%'));
     #array of Employee objects.
-
     or 
     my @emp = $entity->lock(undef, sql_cond('ename', 'LIKE', 'a%'));
     #array of resultset (hash ref)
 
+
 =cut
 
 sub lock {
     my ($self, $class_name, @args) = (@_);
     my $entity_manager = $self->entity_manager;
-    my $condition = $entity_manager->_condition_converter($class_name, @args, $self->filter_condition_values);
+    my $condition = $entity_manager->condition_converter($class_name, @args, $self->filter_condition_values);
     my ($sql, $bind_variables) = $self->SUPER::lock(undef, $condition);
     $self->_execute_query($sql, $bind_variables, $class_name);
 }
@@ -290,18 +258,16 @@ sub lock {
 Return rows for relationship.
 Takes relationship_name, class_name, target_class_name, condition arguments as parameters.
 
-# $user_entity->add_to_many_relationships(sql_relationship(target_entity => $membership_entity, join_columns => ['user_id']));
 
-my $entity_manager = Persistence::Entity::Manager->new(connection_name => 'my_connection');
-$entity_manager->add_entities($membership_entity, $user_entity);
+     $user_entity->add_to_many_relationships(sql_relationship(target_entity => $membership_entity, join_columns => ['user_id']));
+    my $entity_manager = Persistence::Entity::Manager->new(connection_name => 'my_connection');
+    $entity_manager->add_entities($membership_entity, $user_entity);
+    my @membership = $user_entity->relationship_query('wsus_user_service', undef => undef, username => 'test');
+    # returns array of hash refs.
+    or 
+    my @membership = $user_entity->relationship_query('wsus_user_service', 'User' => 'ServiceMembership', username => 'test');
+    # returns array of ServiceMembership objects
 
-my @membership = $user_entity->relationship_query('wsus_user_service', undef => undef, username => 'test');
-# returns array of hash refs.
-
-or 
-
-my @membership = $user_entity->relationship_query('wsus_user_service', 'User' => 'ServiceMembership', username => 'test');
-# returns array of ServiceMembership objects
 
 =cut
 
@@ -309,30 +275,20 @@ sub relationship_query {
     my ($self, $relation_name, $class_name, $target_class_name, @args) = @_;
     my $relationship = $self->relationship($relation_name);
     my $target_entity = $relationship->target_entity;
-    my $condition = $self->entity_manager->_condition_converter($class_name, @args);
+    my $condition = $self->entity_manager->condition_converter($class_name, @args);
     my ($sql, $bind_variables) = $self->SUPER::relationship_query($relation_name, $condition);
     $self->_execute_query($sql, $bind_variables, $target_class_name);
 }
 
 
-=item is_refresh_required
-
-Returns true if refreshis required
-
-=cut
-
-sub is_refresh_required {
-    my ($self, $fields_values) = @_;
-    my $has_primary_key_flag  = $self->has_primary_key_values($fields_values, 1);
-    ! $has_primary_key_flag ;
-}
-
-
 =item insert
 
-Inserts entities' row that is passed in as fields to insert.
+Inserts the entity row
+Takes list of field values.
+
+
+    $entity->insert(col1 => 'val1', col2 => 'val2');
 
-$entity->insert(col1 => 'val1', col2 => 'val2');
 
 =cut
 
@@ -345,32 +301,18 @@ sub insert {
 }
 
 
-=item _autogenerated_values
-
-Adds autogenerated values. Takes hash ref to fields values
-
-=cut
-
-sub _autogenerated_values {
-    my ($self, $field_values) = @_;
-    my $value_generators = $self->value_generators;
-    for my $k(keys %$value_generators) {
-        next if defined $field_values->{$k};
-        my $generator = Persistence::ValueGenerator->generator($value_generators->{$k});
-        $field_values->{$k} = $generator->nextval();
-    }
-}
-
-
 =item relationship_insert
 
-Inserts relation entities' rows that are passed in
-Takes relation name, dataset that represents current entity row, array ref where item
+Inserts the relation rows.
+Takes relation name, dataset that represents  the entity row, array ref where item
 can be either object or hash ref that represents row to be asssociated .
 
-$user_entity->relationship_insert('wsus_user_service', {username => 'test'} , {service_id => 1}, {service_id => 9});
-
-$user_entity->relationship_insert('wsus_user_service', $user, $membership1, $membership1);
+    $user_entity->relationship_insert('wsus_user_service', {username => 'test'} , {service_id => 1}, {service_id => 9});
+    #or
+    my $user = User->new(...);
+    my $membership1 = Membership->new(...);
+    my $membership2 = Membership->new(...);
+    $user_entity->relationship_insert('wsus_user_service', $user, $membership1, $membership2);
 
 =cut
 
@@ -383,78 +325,14 @@ sub relationship_insert {
 }
 
 
-sub _to_many_relationship_insert {
-    my ($self, $relation_name, $dataset, @to_insert) = @_;
-    my $entity_manager = $self->entity_manager;
-    my $relation = $self->relationship($relation_name);
-    my %join_values = $self->_join_columns_values($relation, $dataset);
-    my $target_entity = $relation->target_entity;
-    for my $item (@to_insert) {
-        my $orm = $entity_manager->find_entity_mappings($item);
-        if ($orm) {
-            $orm->update_object($item, \%join_values);
-            $entity_manager->insert($item, \%join_values);
-            
-        } else {
-            $target_entity->insert(%$item, %join_values);
-        }
-    }
-}
-
-
-sub _to_one_relationship_merge {
-    my ($self, $relation_name, $dataset, $to_merge) = @_;
-    my $entity_manager = $self->entity_manager;
-    my $relation = $self->relationship($relation_name);
-    my $target_entity = $relation->target_entity;
-    my $column_values = {};
-    if($to_merge) {
-        my $orm = $entity_manager->find_entity_mappings($to_merge);
-        if ($orm) {
-            $entity_manager->merge($to_merge);
-        } else {
-            $target_entity->merge(%$to_merge);
-        }
-        $column_values = $orm->unique_values($to_merge, $target_entity);
-    }
-    my $join_values = $self->_join_columns_values($relation, $column_values);
-    
-    $self->_merge_datasets($join_values, $dataset);
-}
-
-
-sub _merge_datasets {
-    my ($self, $source_dataset, $target_dataset) = @_;
-    $target_dataset->{$_} = $source_dataset->{$_} for keys %$source_dataset;
-}
-
-
-=item _join_columns_values
-
-Returns join columns values for passed in relation
-
-=cut
-
-sub _join_columns_values {
-    my ($self, $relation, $dataset, $validation) = @_;
-    my $entity = $self->to_one_relationship($relation->name) ? $relation->target_entity : $self;
-    my @join_columns = $relation->join_columns;
-    my @primary_key = $entity->primary_key;
-    my $primary_key_values = $entity->primary_key_values($dataset, $validation);
-    my %result;
-    for my $i (0 .. $#primary_key) {
-        $result{$join_columns[$i]} = $primary_key_values->{$primary_key[$i]};
-    }
-    wantarray ? (%result) : \%result;
-}
-
-
 =item update
 
-Updates entities' row that is passed in as fields to update.
-Takes fields values as hash ref, condition values as hash reference.
+Updates the entity row.
+Takes field values as hash ref, condition values as hash reference.
+
+
+    $entity->update({col1 => 'val1', col2 => 'val2'}, {the_rowid => 'xx'});
 
-$entity->update({col1 => 'val1', col2 => 'val2'}, {the_rowid => 'xx'});
 
 =cut
 
@@ -467,8 +345,12 @@ sub update {
 
 =item merge
 
-Merges entities' row, takes fields to merge as named parameteres,
-$entity->merge(col1 => 'val1', col2 => 'val2', the_rowid => '0xAAFF');
+Merges the entity row.
+Takes field values to merge as named parameteres,
+
+
+    $entity->merge(col1 => 'val1', col2 => 'val2', the_rowid => '0xAAFF');
+
 
 =cut
 
@@ -487,13 +369,16 @@ sub merge {
 
 =item relationship_merge
 
-Merges relation entities' rows that are passed in.
-Takes relation name, dataset that represents current entity row, array ref where item
-can be either object or hash ref that represent asssociated row to merge.
+Merges the relation rows.
+Takes relation name, dataset that represents  the entity row, list of
+either object or hash ref that represent asssociated row to merge.
+
+
+    $user_entity->relationship_merge('wsus_user_service',
+        {username => 'test'} ,
+        {service_id => 1, agreement_flag => 1}, {service_id => 5, agreement_flag => 1}
+    );
 
-$user_entity->relationship_merge('wsus_user_service',
-    {username => 'test'} ,
-    {service_id => 1, agreement_flag => 1}, {service_id => 5, agreement_flag => 1});
 
 =cut
 
@@ -506,45 +391,14 @@ sub relationship_merge {
 }
 
 
-sub _to_many_relationship_merge {
-    my ($self, $relation_name, $dataset, @to_merge) = @_;
-    my $entity_manager = $self->entity_manager;
-    my $relation = $self->relationship($relation_name);
-    my %join_values = $self->_join_columns_values($relation, $dataset, 1);
-    my @existing_dataset = $self->relationship_query($relation_name, undef => undef, %join_values);
-    
-    my $target_entity = $relation->target_entity;
-    my %rows_pk;
-    my $column_values;
-    for my $item (@to_merge) {
-        my $orm = $entity_manager->find_entity_mappings($item);
-        if ($orm) {
-            $orm->update_object($item, \%join_values);
-            $entity_manager->merge($item, \%join_values);
-            $column_values = $orm->unique_values($item, $target_entity);
-        } else {
-            $column_values = {%$item, %join_values};
-            $target_entity->merge(%$item, %join_values);
-        }
-        
-        my $pk_values = $target_entity->primary_key_values($column_values, 1);
-        $rows_pk{join("-", %$pk_values)} = 1;
-    }
-    
-    #deletes all rows that are not part of the assocaition.
-    for my $record (@existing_dataset) {
-        my $pk_values = $target_entity->primary_key_values($record, 1);
-        next if $rows_pk{join("-", %$pk_values)};
-        $target_entity->delete(%$pk_values);
-    }
-}
-
-
 =item delete
 
-Delete entities' row that meets passed in condition values
-Takes condition values.
-$entity->delete(the_rowid => 'xx');
+Delete entity row.
+Takes list of condition values.
+
+
+    $entity->delete(the_rowid => 'xx');
+
 
 =cut
 
@@ -557,13 +411,14 @@ sub delete {
 
 =item relationship_delete
 
-Inserts relation entities' row that is passed in as fields to insert.
-Takes relation name, dataset that represents current entity row, array ref where item
-can be either associated object or hash ref that represent asssociated row.
+Deletes associated rows.
+Takes relation name, dataset that represents  the entity row, list of 
+either associated object or hash ref that represent asssociated row.
 
-$user_entity->relationship_insert('wsus_user_service', {username => 'test'} , {service_id => 1}, {service_id => 9});
 
-$user_entity->relationship_insert('wsus_user_service', $user, $membership1, $membership1);
+    $user_entity->relationship_insert('wsus_user_service', {username => 'test'} , {service_id => 1}, {service_id => 9});
+    $user_entity->relationship_insert('wsus_user_service', $user, $membership1, $membership1);
+
 
 =cut
 
@@ -576,45 +431,10 @@ sub relationship_delete {
 }
 
 
-sub _to_many_relationship_delete {
-    my ($self, $relation_name, $dataset, @to_delete) = @_;
-    my $entity_manager = $self->entity_manager;
-    my $relation = $self->relationship($relation_name);
-    my %join_values = $self->_join_columns_values($relation, $dataset, 1);
-    my $target_entity = $relation->target_entity;
-    for my $item (@to_delete) {
-        my $orm = $entity_manager->find_entity_mappings($item);
-        if($orm) {
-            $orm->update_object($item, \%join_values);
-            $entity_manager->delete($item);
-        } else {
-            $target_entity->delete($target_entity->unique_condition_values({%$item, %join_values}, 1));
-        }
-    }
-}
-
-
-sub _to_one_relationship_delete {
-    my ($self, $relation_name, $dataset, $to_delete) = @_;
-    my $entity_manager = $self->entity_manager;
-    my $relation = $self->relationship($relation_name);
-    my $target_entity = $relation->target_entity;
-    my $column_values = {};
-    if($to_delete) {
-        my $orm = $entity_manager->find_entity_mappings($to_delete);
-        if ($orm) {
-            $entity_manager->delete($to_delete);
-        } else {
-            $target_entity->delete(%$to_delete);
-        }
-    }
-}
-
-
 =item primary_key_values
 
 Returns primary key values.
-Takes fields values that will be used as condition to retrive primary key values
+Takes field values that will be used as condition to retrive primary key values
 in case they are not contain primary key values.
 
 =cut
@@ -656,9 +476,261 @@ sub has_primary_key_values {
 }
 
 
+=back
+
+=head2 PRIVATE METHODS
+
+=over
+
+=item is_refresh_required
+
+Returns true if refreshis required
+
+=cut
+
+sub is_refresh_required {
+    my ($self, $fields_values) = @_;
+    my $has_primary_key_flag  = $self->has_primary_key_values($fields_values, 1);
+    ! $has_primary_key_flag ;
+}
+
+
+=item run_event
+
+Executes passed in even.
+Takes event name, event parameters.
+
+=cut
+
+sub run_event {
+    my ($self, $name, @args) = @_;
+    my $event = $self->trigger($name);
+    $event->(@args) if $event;
+}
+
+
+=item validate_trigger
+
+Validates triggers types.
+The following trigger types are supported: before_insert, after_insert, before_update, after_update, before_delete, after_delete, on_fetch.
+
+=cut
+
+{
+    my @triggers = qw(before_insert after_insert before_update after_update before_delete after_delete on_fetch);
+    sub validate_trigger {
+        my ($self, $name, $value) = @_;
+        confess "invalid trigger name: $name , must be one of " . join(",", @triggers)
+            unless (grep {$name eq $_} @triggers);
+        confess "secound parameter must be a callback"
+            unless ref($value) eq 'CODE';
+    }
+}
+
+
+=item _autogenerated_values
+
+Adds autogenerated values. Takes hash ref to field values
+
+=cut
+
+sub _autogenerated_values {
+    my ($self, $field_values) = @_;
+    my $value_generators = $self->value_generators;
+    for my $k(keys %$value_generators) {
+        next if defined $field_values->{$k};
+        my $generator = Persistence::ValueGenerator->generator($value_generators->{$k});
+        $field_values->{$k} = $generator->nextval();
+    }
+}
+
+
+=item _to_many_relationship_insert
+
+Insert data to many relationship.
+Takes relationship name, hashref of the fileds values for the entity,
+list of hash ref that contians fileds values of the entities to associate.
+
+=cut
+
+sub _to_many_relationship_insert {
+    my ($self, $relation_name, $dataset, @to_insert) = @_;
+    my $entity_manager = $self->entity_manager;
+    my $relation = $self->relationship($relation_name);
+    my %join_values = $self->_join_columns_values($relation, $dataset);
+    my $target_entity = $relation->target_entity;
+    for my $item (@to_insert) {
+        my $orm = $entity_manager->find_entity_mappings($item);
+        if ($orm) {
+            $orm->update_object($item, \%join_values);
+            $entity_manager->insert($item, \%join_values);
+            
+        } else {
+            $target_entity->insert(%$item, %join_values);
+        }
+    }
+}
+
+
+=item _to_one_relationship_merge
+
+Merges data to one relationship.
+Takes relationship name, hashref of the fileds values for the entity,
+list of hash ref that contians values fileds of the entities to associate.
+
+=cut
+
+sub _to_one_relationship_merge {
+    my ($self, $relation_name, $dataset, $to_merge) = @_;
+    my $entity_manager = $self->entity_manager;
+    my $relation = $self->relationship($relation_name);
+    my $target_entity = $relation->target_entity;
+    my $column_values = {};
+    if($to_merge) {
+        my $orm = $entity_manager->find_entity_mappings($to_merge);
+        if ($orm) {
+            $entity_manager->merge($to_merge);
+        } else {
+            $target_entity->merge(%$to_merge);
+        }
+        $column_values = $orm->unique_values($to_merge, $target_entity);
+    }
+    my $join_values = $self->_join_columns_values($relation, $column_values);
+    $self->_merge_datasets($join_values, $dataset);
+}
+
+
+
+=item _merge_datasets
+
+Mergers tow passed in dataset.
+Takes source hash_ref, target hash_ref.
+
+=cut
+
+sub _merge_datasets {
+    my ($self, $source_dataset, $target_dataset) = @_;
+    $target_dataset->{$_} = defined $source_dataset->{$_} ? $source_dataset->{$_} : $target_dataset->{$_}
+        for keys %$source_dataset;
+}
+
+
+=item _join_columns_values
+
+Returns join columns values for passed in relation
+
+=cut
+
+sub _join_columns_values {
+    my ($self, $relation, $dataset, $validation) = @_;
+    my $entity = $self->to_one_relationship($relation->name) ? $relation->target_entity : $self;
+    my @join_columns = $relation->join_columns;
+    my @primary_key = $entity->primary_key;
+    my $primary_key_values = $entity->primary_key_values($dataset, $validation);
+    my %result;
+    for my $i (0 .. $#primary_key) {
+        $result{$join_columns[$i]} = $primary_key_values->{$primary_key[$i]};
+    }
+    wantarray ? (%result) : \%result;
+}
+
+
+=item _to_many_relationship_merge
+
+Marges to many relationship rows (insert/update).
+Takes relationship name, hashref of the fileds values for the entity,
+list of hash ref that contians values fileds of the entities to merge.
+
+=cut
+
+sub _to_many_relationship_merge {
+    my ($self, $relation_name, $dataset, @to_merge) = @_;
+    my $entity_manager = $self->entity_manager;
+    my $relation = $self->relationship($relation_name);
+    my %join_values = $self->_join_columns_values($relation, $dataset, 1);
+    my @existing_dataset = $self->relationship_query($relation_name, undef => undef, %join_values);
+    my $target_entity = $relation->target_entity;
+    my %rows_pk;
+    my $column_values;
+    for my $item (@to_merge) {
+        my $orm = $entity_manager->find_entity_mappings($item);
+        if ($orm) {
+            $orm->update_object($item, \%join_values);
+            $entity_manager->merge($item, \%join_values);
+            $column_values = $orm->unique_values($item, $target_entity);
+        } else {
+            $column_values = {%$item, %join_values};
+            $target_entity->merge(%$item, %join_values);
+        }
+        
+        my $pk_values = $target_entity->primary_key_values($column_values, 1);
+        $rows_pk{join("-", %$pk_values)} = 1;
+    }
+    
+    #deletes all rows that are not part of the assocaition.
+    for my $record (@existing_dataset) {
+        my $pk_values = $target_entity->primary_key_values($record, 1);
+        next if $rows_pk{join("-", %$pk_values)};
+        $target_entity->delete(%$pk_values);
+    }
+}
+
+
+=item _to_many_relationship_delete
+
+Deletes to many relationship association.
+Takes relationship name, hashref of the fileds values for the entity,
+list of hash ref that contians values fileds of the entities to delete.
+
+=cut
+
+sub _to_many_relationship_delete {
+    my ($self, $relation_name, $dataset, @to_delete) = @_;
+    my $entity_manager = $self->entity_manager;
+    my $relation = $self->relationship($relation_name);
+    my %join_values = $self->_join_columns_values($relation, $dataset, 1);
+    my $target_entity = $relation->target_entity;
+    for my $item (@to_delete) {
+        my $orm = $entity_manager->find_entity_mappings($item);
+        if($orm) {
+            $orm->update_object($item, \%join_values);
+            $entity_manager->delete($item);
+        } else {
+            $target_entity->delete($target_entity->unique_condition_values({%$item, %join_values}, 1));
+        }
+    }
+}
+
+
+=item _to_one_relationship_delete
+
+Deletes to one relationship association.
+Takes relationship name, hashref of the fileds values for the entity,
+list of hash ref that contians values fileds of the entities to delete.
+
+=cut
+
+sub _to_one_relationship_delete {
+    my ($self, $relation_name, $dataset, $to_delete) = @_;
+    my $entity_manager = $self->entity_manager;
+    my $relation = $self->relationship($relation_name);
+    my $target_entity = $relation->target_entity;
+    my $column_values = {};
+    if($to_delete) {
+        my $orm = $entity_manager->find_entity_mappings($to_delete);
+        if ($orm) {
+            $entity_manager->delete($to_delete);
+        } else {
+            $target_entity->delete(%$to_delete);
+        }
+    }
+}
+
+
 =item retrive_primary_key_values
 
 Retrieves primary key values.
+Takes hash ref of the entity field values.
 
 =cut
 
@@ -673,6 +745,7 @@ sub retrive_primary_key_values {
 =item _execute_statement
 
 Executes passed in sql statements with all callback defined by decorators (triggers)
+Takes sql, array ref of the bind varaibles,r event name, event parameters.
 
 =cut
 
@@ -687,7 +760,8 @@ sub _execute_statement {
 
 =item _execute_query
 
-Executes query
+Executes query.
+Takes sql, array ref of the bind varaibles, optionally class name.
 
 =cut
 
