@@ -2,6 +2,9 @@ package Persistence::Entity::Manager;
 
 use strict;
 use warnings;
+use vars qw($VERSION);
+
+$VERSION = 0.02;
 
 use Abstract::Meta::Class ':all';
 use Persistence::ORM;
@@ -60,13 +63,13 @@ use SQL::Entity::Condition ':all';
         $entity_manager->begin_work;
         eval {
             my $emp = Employee->new(name => 'foo');
-            $manager->insert($user);
+            $entity_manager->insert($user);
 
 
             $emp->set_deptno(10);
-            $manager->update($emp);
+            $entity_manager->update($emp);
 
-            $manager->delete($emp)
+            $entity_manager->delete($emp)
 
             my ($emp) = $entity_manager->find(emp => 'Employee', name => 'foo');
 
@@ -81,7 +84,7 @@ use SQL::Entity::Condition ':all';
 
 =head1 DESCRIPTION
 
-Entity manager.
+Represets entity manager.
 
 =head1 EXPORT
 
@@ -98,6 +101,17 @@ None.
 has '$.name' => (required => 1);
 
 
+
+=item active_transaction
+
+Flag that stores information if manager is in active transaction.
+
+=cut
+
+has '$.active_transaction';
+
+
+
 =item entities
 
 =cut
@@ -144,17 +158,19 @@ has '$._connection' => (transistent => 1);
 
 =item persitence_mangement
 
-If this option is set, then state of the all merged or created object by entity manager will be tracked 
+If this option is set, then state of the all fetched, merged or created object by entity manager will be tracked 
 (it's database state is stored in local cache),
-unless thay become detached by calling $entity_manager->detach($obj) or $entity_manager->detach_all
+unless they become detached by calling $entity_manager->detach($obj) or $entity_manager->detach_all
 or for persitence_mangement = transaction
-$entity_manager->commit, $entity_manager->rollback 
+
+    $entity_manager->commit;
+    $entity_manager->rollback;
 
 Note:
 Using this option you must ensure that there are not obsolete objects in the local cache by detching all objects
 that are no longer in use, it may be resource consuming (memory).
 
-If persitence_mangement is not set then extra sql will be issued to get object state from database for update, delete.
+If the persitence_mangement option is not set then extra sql will be issued to get object state from database for update, delete.
 
 =cut
 
@@ -186,6 +202,7 @@ has '%._lazy_fetch_flags' => (item_accessor => '_lazy_fetch_flag');
 
 =cut
 
+
 {   my %managers;
 
 =item initialise
@@ -200,7 +217,12 @@ has '%._lazy_fetch_flags' => (item_accessor => '_lazy_fetch_flag');
 
 =item manager
 
-Return entity amanger object, takes entity manager name
+Return entity manger object, takes entity manager name as parameter.
+
+    Persistence::Entity::Manager->new(name => 'manager_name', connection_name => 'connection_nane');
+    #
+    my $entity_manager = Persistence::Entity::Manager->manager('manager_name');
+
 
 =cut
 
@@ -213,6 +235,413 @@ Return entity amanger object, takes entity manager name
 }
 
 
+=item find
+
+Returns list of objects or resultsets.
+Takes entity name, class name to which resultset will be casted,
+(if class name is undef then hash ref will be return instead),
+list of names parameters that will be used as condition or condition object.
+For non empty class name resulset state is cached - persitence_mangement option.
+
+Note: If class name has the ORM mapping, then name parameters
+must be objects' attributs . Condition object always should use entity column.
+
+
+    my ($emp) = $entity_manager->find(emp => 'Employee', name => 'adrian');
+    or
+
+    my @emp = $entity_manager->find(emp => 'Employee', sql_cond('ename', 'LIKE', 'a%'));
+    #array of Employee objects.
+
+    or 
+    my @emp = $entity_manager->find(emp => undef, sql_cond('ename', 'LIKE', 'a%'));
+    #array of resultset (hash ref)
+
+
+=cut
+
+sub find {
+    my ($self, $entity_name, $class_name, @args) = (@_);
+    my $entity = $self->entity($entity_name) or confess "cant find entity ${entity_name}";
+    $entity->find($class_name, @args);
+}
+
+
+=item lock
+
+Returns and locks list and of objects or resultsets.
+Takes entity name, class name to which resultset will be casted,
+(if class name is undef then hash ref will be return instead),
+list of names parameters that will be used as condition or condition object.
+For non empty class name resulset state is cached - persitence_mangement option.
+
+Note: If class name has the ORM mapping, then name parameters
+must be objects' attributs . Condition object always should use entity column.
+
+
+    my ($emp) = $entity_manager->find(emp => 'Employee', name => 'adrian');
+    or
+
+    my @emp = $entity_manager->find(emp => 'Employee', sql_cond('ename', 'LIKE', 'a%'));
+    #array of Employee objects.
+
+    or 
+    my @emp = $entity_manager->find(emp => undef, sql_cond('ename', 'LIKE', 'a%'));
+    #array of resultset (hash ref)
+
+
+=cut
+
+sub lock {
+    my ($self, $entity_name, $class_name, @args) = (@_);
+    my $entity = $self->entity($entity_name) or confess "cant find entity ${entity_name}";
+    $entity->lock($class_name, @args);
+}
+
+
+=item condition_converter
+
+Converts list of parameters to condition object.
+Takes class name, list of condition parameters.
+Note: If class name has the ORM mapping, then name parameters
+must be objects' attributs . Condition object always should use entity column.
+
+
+    my $sql_condition = $entity_manager->condition_converter('Employee', name => 'adrian');
+    #creates ename = 'adrian'  sql condition (given that there is mapping between ename column to name attribute).
+
+
+See also L<SQL::Entity::Condition>
+
+=cut
+
+sub condition_converter {
+    my ($self, $class_name, @args) = @_;
+    my $orm = $self->find_entity_mappings($class_name);
+    (@args > 1)
+        ? SQL::Entity::Condition->struct_to_condition(
+            ($orm ? $orm->map_attributes_to_column_values(@args) : @args))
+        : $args[0];
+}
+
+
+=item query
+
+Returns new query object.
+Takes entity name, optionally class name to which resultset will be casted,
+(if class name is undef then hash ref will be return instead),
+For non empty class name resulset state is cached - persitence_mangement option.
+
+    my $query = $entity_manager->query(emp => undef);
+    $query->set_offset(20);
+    $query->set_limit(5);
+    my @emp = $query->execute(['empno', 'ename']);
+
+    $query->set_offset(120);
+    $query->set_limit(5);
+    my @emp = $query->execute(undef, deptnp => 10);
+
+
+See also L<Persistence::Entity::Query>
+
+=cut
+
+sub query {
+    my ($self, $entity_name, $class_name) = (@_);
+    my $orm = $self->find_entity_mappings($class_name);
+    my $entity = $self->entity($entity_name) or confess "cant find entity ${entity_name}";
+    my $connection = $self->connection;
+    my $dbms_name = $connection->dbms_name;
+    my $key = $entity->name ."_${dbms_name}_" . ($class_name ||'');
+    my $query = $self->_query($key);
+    unless($query) {
+        $query = Persistence::Entity::Query->new(
+            name            => $key,
+            entity          => $entity,
+            dialect         => $connection->dbms_name,
+            cursor_callback => sub {
+                my ($this, $sql, $bind_variables) = @_;
+                $this->query_setup($connection);
+                $entity->_execute_query($sql, $bind_variables, $class_name);
+            },
+            condition_converter_callback => sub {
+                my (@args) = @_;
+                $self->condition_converter($class_name, @args);
+            }
+        );
+        $self->add_queries($query);
+    }
+    $query;
+}
+
+
+=item refersh
+
+Refresh object's state.
+Takes object as parameter.
+
+
+    my $emp = Emp->new(id => 10);
+    $entity_manager->refresh($emp);
+
+Refresh operation caches object - persitence_mangement option.
+
+=cut
+
+sub refersh {
+    my ($self, $object) = @_;
+    my $orm = $self->find_entity_mappings($object, 1);
+    $self->_reset_lazy_relation_attributes($object);
+    $self->detach($object);
+    my $entity = $self->entity($orm->entity_name);
+    my %fields_values = $orm->map_object_attributes_to_column_values($object);
+    my %condition_values = $entity->unique_condition_values(\%fields_values, 1);
+    my ($resultset) = $entity->find(undef, %condition_values);
+    $orm->update_object($object, $resultset);
+    $self->_manage_object($object, $resultset);
+    $orm->deserialise_eager_relation_attributes($object, $self);
+    $object;
+}
+
+
+=item insert
+
+Inserts object that is mapped to the entity, takes the object as parameter
+
+
+    my $emp = Emp->new(id => 10, name => 'scott');
+    $entity_manager->insert($emp);
+
+
+=cut
+
+sub insert {
+    my ($self, $object, $values) = @_;
+    $values ||= {};
+    my $orm = $self->find_entity_mappings($object, 1);
+    my %fields_values = ($orm->map_object_attributes_to_column_values($object), %$values);
+    my $entity = $self->entity($orm->entity_name);
+    $self->_insert_to_one_relationship($entity, $object, \%fields_values, $orm);
+    $orm->run_event('before_insert', \%fields_values);
+    my $fields_values = $entity->insert(%fields_values);
+    $self->_update_generated_values($orm, $entity, $object, $fields_values);
+    my $refresh_required_flag = $entity->is_refresh_required($fields_values);
+    $self->refersh($object)  if $refresh_required_flag;
+    my %unique_values = $entity->unique_condition_values($fields_values);
+    $self->_insert_to_many_relationship($entity, $object, {$entity->unique_condition_values($fields_values)}, $orm);
+    $orm->run_event('after_insert', $fields_values);
+    $self->_manage_object($object, $fields_values);
+}
+
+
+=item update
+
+Updates object that is mapped to the entity, takes the object as parameter
+
+    my $emp = Emp->new(id => 10, name => 'scott');
+    $entity_manager->update($emp);
+
+
+=cut
+
+sub update {
+    my ($self, $object, $values) = @_;
+    $values ||= {};
+    my $orm = $self->find_entity_mappings($object, 1);
+    my $entity = $self->entity($orm->entity_name);
+    $orm->deserialise_lazy_relation_attributes($object, $self);
+    $self->initialise_operation($orm->entity_name, $object);
+    my %fields_values = ($orm->map_object_attributes_to_column_values($object), %$values);
+    $self->_update_to_one_relationship($entity, $object, \%fields_values, $orm);
+    my $changed_column_values = $self->changed_column_values($entity, $object, \%fields_values);
+    my %unique_values = $entity->unique_condition_values(\%fields_values);
+    if ($changed_column_values) {
+        $orm->run_event('before_update', \%fields_values);
+        $entity->update($changed_column_values, \%unique_values);
+    }
+    $self->_update_to_many_relationship($entity, $object, \%unique_values, $orm);
+    $self->complete_operation($orm->entity_name, $object);
+    if ($changed_column_values) {
+        $orm->run_event('after_update', \%fields_values);
+        $self->_manage_object($object, \%fields_values);
+    }
+    
+}
+
+
+=item merge
+
+Merges object that is mapped to the entity, takes the object as parameter
+Is robject exists in database the updates, otherwise inserts.
+
+
+    my $emp = Emp->new(id => 10, name => 'scott');
+    $entity_manager->merge($emp);
+
+
+
+=cut
+
+sub merge {
+    my ($self, $object, $values) = @_;
+    my $orm = $self->find_entity_mappings($object, 1);
+    return if $self->has_pending_operation($orm->entity_name);
+    my $entity = $self->entity($orm->entity_name);
+    my %fields_values = $orm->unique_values($object, $entity);
+    my ($result) = $entity->find(undef, $entity->unique_condition_values(\%fields_values));
+    unless ($result) {
+        $self->insert($object, $values);
+    } else {
+        $self->_update_pk_values($orm, $entity, $object, $result)
+          unless $entity->has_primary_key_values(\%fields_values);
+        $self->update($object, $values);
+    }
+}
+
+
+
+=item delete
+
+Delets object that is mapped to the entity, takes object as parameter
+
+
+    my $emp = Emp->new(id => 10, name => 'scott');
+    $entity_manager->delete($emp);
+
+
+=cut
+
+sub delete {
+    my ($self, $object) = @_;
+    my $orm = $self->find_entity_mappings($object, 1);
+    return if $self->has_pending_operation($orm->entity_name);
+    $orm->deserialise_lazy_relation_attributes($object, $self);
+    $self->initialise_operation($orm->entity_name, $object);
+    my $entity = $self->entity($orm->entity_name);
+    my %fields_values = ($orm->map_object_attributes_to_column_values($object));
+    my %condition_values = $entity->unique_condition_values(\%fields_values);
+    $orm->run_event('before_delete', \%condition_values);
+    $self->_delete_to_many_relationship($entity, $object, \%condition_values, $orm);
+    $entity->delete(%condition_values);
+    $self->_delete_to_one_relationship($entity, $object, \%condition_values, $orm);
+    $self->complete_operation($orm->entity_name);
+    $orm->run_event('after_delete', \%condition_values);
+    $self->detach($object);
+}
+
+
+=item begin_work
+
+Begins a new transaction.
+
+   $entity_manager->begin_work;
+    eval {
+        my $emp = Employee->new(name => 'foo');
+        $entity_manager->insert($user);
+        $entity_manager->commit;
+    }
+    $entity_manager->rollback if $@;
+
+=cut
+
+sub begin_work {
+    my ($self) = @_;
+    confess "has already active transaction"
+        if $self->active_transaction;
+    $self->connection->begin_work;
+    $self->set_active_transaction(1);
+}
+
+
+=item commit
+
+Commits current transaction.
+
+    $entity_manager->commit;
+
+=cut
+
+sub commit {
+    my ($self) = @_;
+    $self->set_active_transaction(0);
+    $self->connection->commit;
+    my $persitence_mangement = $self->persitence_mangement;
+    $self->detach_all
+        if ($persitence_mangement  && $persitence_mangement eq 'transation');
+}
+
+
+=item rollback
+
+Rollbacks current transaction.
+
+    $entity_manager->reollback;
+
+=cut
+
+sub rollback {
+    my ($self) = @_;
+    $self->set_active_transaction(0);
+    $self->connection->rollback;
+    my $persitence_mangement = $self->persitence_mangement;
+    $self->detach_all
+        if ($persitence_mangement  && $persitence_mangement eq 'transation');
+}
+
+
+
+=item detach
+
+Removes database object state from cache.
+
+....$entity_manager->search()
+    $entity_manager->detach
+
+=cut
+
+sub detach {
+    my ($self, $object) = @_;
+    my $persistence_cache = $self->_persistence_cache;
+    my $lazy_fetch_flags = $self->_lazy_fetch_flags;
+    delete $persistence_cache->{$object};
+    delete $lazy_fetch_flags->{$object};
+}
+
+
+=item detach_all
+
+Clears entity cache.
+
+=cut
+
+sub detach_all {
+    my $self = shift;
+    $self->set__persistence_cache({});
+    $self->set__lazy_fetch_flags({});
+}
+
+
+=item connection
+
+Returns connection object.
+
+=cut
+
+sub connection {
+    my ($self) = @_;
+    my $connection = $self->_connection;
+    unless($connection) {
+        $connection = $self->_connection(DBIx::Connection->connection($self->connection_name));
+    }
+    $connection;
+}
+
+
+=back
+
+=head2 PRIVATE METHODS
+
+=over
 
 =item initialise_operation
 
@@ -265,157 +694,6 @@ sub find_entity_mappings {
     $result;
 }
 
-=item find
-
-Returns list of objects or resultsets for passed in entity that meets passed in condition
-Takes entity name, class name to which resultset will be casted,
-(if class name is undef then hash ref will be return instead), list of names parameters that will
-be used as condition or condition object.  If class name has the ORM mapping, then name parameters
-must be objects' attributs . Condition object always should use entity column.
-
-    my ($emp) = $entity_manager->find(emp => 'Employee', name => 'adrian');
-    or
-
-    my @emp = $entity_manager->find(emp => 'Employee', sql_cond('ename', 'LIKE', 'a%'));
-    #array of Employee objects.
-
-    or 
-    my @emp = $entity_manager->find(emp => undef, sql_cond('ename', 'LIKE', 'a%'));
-    #array of resultset (hash ref)
-
-=cut
-
-sub find {
-    my ($self, $entity_name, $class_name, @args) = (@_);
-    my $entity = $self->entity($entity_name) or confess "cant find entity ${entity_name}";
-    $entity->find($class_name, @args);
-}
-
-
-=item lock
-
-Returns and locks list and of objects or resultsets for passed in entity that meets passed in condition
-Takes entity name, class name to which resultset will be casted,
-(if class name is undef then hash ref will be return instead), list of names parameters that will
-be used as condition or condition object.  If class name has the ORM mapping, then name parameters
-must be objects' attributs . Condition object always should use entity column.
-
-    my ($emp) = $entity_manager->find(emp => 'Employee', name => 'adrian');
-    or
-
-    my @emp = $entity_manager->find(emp => 'Employee', sql_cond('ename', 'LIKE', 'a%'));
-    #array of Employee objects.
-
-    or 
-    my @emp = $entity_manager->find(emp => undef, sql_cond('ename', 'LIKE', 'a%'));
-    #array of resultset (hash ref)
-
-=cut
-
-sub lock {
-    my ($self, $entity_name, $class_name, @args) = (@_);
-    my $entity = $self->entity($entity_name) or confess "cant find entity ${entity_name}";
-    $entity->lock($class_name, @args);
-}
-
-
-=item _condition_converter
-
-Converts
-
-=cut
-
-sub _condition_converter {
-    my ($self, $class_name, @args) = @_;
-    my $orm = $self->find_entity_mappings($class_name);
-    (@args > 1)
-        ? SQL::Entity::Condition->struct_to_condition(
-            ($orm ? $orm->map_attributes_to_column_values(@args) : @args))
-        : $args[0];
-}
-
-
-=item query
-
-Returns new query object.
-Takes entity name, optionally class name.
-
-=cut
-
-sub query {
-    my ($self, $entity_name, $class_name) = (@_);
-    my $orm = $self->find_entity_mappings($class_name);
-    my $entity = $self->entity($entity_name) or confess "cant find entity ${entity_name}";
-    my $connection = $self->connection;
-    my $dbms_name = $connection->dbms_name;
-    my $key = $entity->name ."_${dbms_name}_" . ($class_name ||'');
-    my $query = $self->_query($key);
-    unless($query) {
-        $query = Persistence::Entity::Query->new(
-            name            => $key,
-            entity          => $entity,
-            dialect         => $connection->dbms_name,
-            cursor_callback => sub {
-                my ($this, $sql, $bind_variables) = @_;
-                $this->query_setup($connection);
-                $entity->_execute_query($sql, $bind_variables, $class_name);
-            },
-            condition_converter_callback => sub {
-                my (@args) = @_;
-                $self->_condition_converter($class_name, @args);
-            }
-        );
-        $self->add_queries($query);
-    }
-    $query;
-}
-
-
-=item refersh
-
-Refresh object's data
-
-=cut
-
-sub refersh {
-    my ($self, $object) = @_;
-    my $orm = $self->find_entity_mappings($object, 1);
-    $self->detach($object);
-    my $entity = $self->entity($orm->entity_name);
-    my %fields_values = $orm->map_object_attributes_to_column_values($object);
-    my %condition_values = $entity->unique_condition_values(\%fields_values, 1);
-    my ($resultset) = $entity->find(undef, %condition_values);
-    $orm->update_object($object, $resultset);
-    $self->_manage_object($object, $resultset);
-    $orm->deserialise_eager_relation_attributes($object, $self);
-    $object;
-}
-
-
-=item insert
-
-Inserts object that is mapped to the entity, takes the object as parameter
-
-=cut
-
-sub insert {
-    my ($self, $object, $values) = @_;
-    $values ||= {};
-    my $orm = $self->find_entity_mappings($object, 1);
-    my %fields_values = ($orm->map_object_attributes_to_column_values($object), %$values);
-    my $entity = $self->entity($orm->entity_name);
-    $self->_insert_to_one_relationship($entity, $object, \%fields_values, $orm);
-    $orm->run_event('before_insert', \%fields_values);
-    my $fields_values = $entity->insert(%fields_values);
-    $self->_update_generated_values($orm, $entity, $object, $fields_values);
-    my $refresh_required_flag = $entity->is_refresh_required($fields_values);
-    $self->refersh($object)  if $refresh_required_flag;
-    my %unique_values = $entity->unique_condition_values($fields_values);
-    $self->_insert_to_many_relationship($entity, $object, {$entity->unique_condition_values($fields_values)}, $orm);
-    $orm->run_event('after_insert', $fields_values);
-    $self->_manage_object($object, $fields_values);
-}
-
 
 =item _update_generated_values
 
@@ -444,6 +722,9 @@ sub _insert_to_many_relationship {
 }
 
 
+=item _insert_to_one_relationship
+
+=cut
 
 sub _insert_to_one_relationship {
     my ($self, $entity, $object, $unique_values, $orm) = @_;
@@ -454,59 +735,10 @@ sub _insert_to_one_relationship {
 }
 
 
-=item update
-
-Updates object that is mapped to the entity, takes the object as parameter
+=item _update_pk_values
 
 =cut
 
-sub update {
-    my ($self, $object, $values) = @_;
-    $values ||= {};
-    my $orm = $self->find_entity_mappings($object, 1);
-    my $entity = $self->entity($orm->entity_name);
-    $self->initialise_operation($orm->entity_name, $object);
-    my %fields_values = ($orm->map_object_attributes_to_column_values($object), %$values);
-    $self->_update_to_one_relationship($entity, $object, \%fields_values, $orm);
-    my $changed_column_values = $self->changed_column_values($entity, $object, \%fields_values);
-    my %unique_values = $entity->unique_condition_values(\%fields_values);
-    if ($changed_column_values) {
-        $orm->run_event('before_update', \%fields_values);
-        $entity->update($changed_column_values, \%unique_values);
-    }
-    $self->_update_to_many_relationship($entity, $object, \%unique_values, $orm);
-    $self->complete_operation($orm->entity_name, $object);
-    if ($changed_column_values) {
-        $orm->run_event('after_update', \%fields_values);
-        $self->_manage_object($object, \%fields_values);
-    }
-    
-}
-
-
-=item merge
-
-Merges object that is mapped to the entity, takes the object as parameter
-
-=cut
-
-sub merge {
-    my ($self, $object, $values) = @_;
-    my $orm = $self->find_entity_mappings($object, 1);
-    return if $self->has_pending_operation($orm->entity_name);
-    my $entity = $self->entity($orm->entity_name);
-    my %fields_values = $orm->unique_values($object, $entity);
-    my ($result) = $entity->find(undef, $entity->unique_condition_values(\%fields_values));
-    unless ($result) {
-        $self->insert($object, $values);
-    } else {
-        $self->_update_pk_values($orm, $entity, $object, $result)
-          unless $entity->has_primary_key_values(\%fields_values);
-        $self->update($object, $values);
-    }
-}
-
-
 sub _update_pk_values {
     my ($self, $orm, $entity, $object, $fields_values) = @_;
     my $pk = $entity->primary_key or return;
@@ -514,6 +746,10 @@ sub _update_pk_values {
 }
 
 
+=item _update_to_many_relationship
+
+=cut
+
 sub _update_to_many_relationship {
     my ($self, $entity, $object, $unique_values, $orm) = @_;
     my @relations = Persistence::Relationship->updatable_to_many_relations(ref $object);
@@ -523,6 +759,10 @@ sub _update_to_many_relationship {
 }
 
 
+=item _update_to_one_relationship
+
+=cut
+
 sub _update_to_one_relationship {
     my ($self, $entity, $object, $unique_values, $orm) = @_;
     my @relations = Persistence::Relationship->updatable_to_one_relations(ref $object);
@@ -532,30 +772,6 @@ sub _update_to_one_relationship {
 }
 
 
-=item delete
-
-Delets object that is mapped to the entity, takes object as parameter
-
-=cut
-
-sub delete {
-    my ($self, $object) = @_;
-    my $orm = $self->find_entity_mappings($object, 1);
-    return if $self->has_pending_operation($orm->entity_name);
-    $self->initialise_operation($orm->entity_name, $object);
-    my $entity = $self->entity($orm->entity_name);
-    my %fields_values = ($orm->map_object_attributes_to_column_values($object));
-    my %condition_values = $entity->unique_condition_values(\%fields_values);
-    $orm->run_event('before_delete', \%condition_values);
-    $self->_delete_to_many_relationship($entity, $object, \%condition_values, $orm);
-    $entity->delete(%condition_values);
-    $self->_delete_to_one_relationship($entity, $object, \%condition_values, $orm);
-    $self->complete_operation($orm->entity_name);
-    $orm->run_event('after_delete', \%condition_values);
-    $self->detach($object);
-}
-
-
 =item _delete_to_many_relationship
 
 =cut
@@ -569,7 +785,6 @@ sub _delete_to_many_relationship {
 }
 
 
-
 =item _delete_to_one_relationship
 
 =cut
@@ -638,41 +853,6 @@ sub changed_column_values {
 }
 
 
-=item begin_work
-
-=cut
-
-sub begin_work {
-    my ($self) = @_;
-    $self->connection->begin_work;
-}
-
-
-=item commit
-
-=cut
-
-sub commit {
-    my ($self) = @_;
-    $self->connection->commit;
-    my $persitence_mangement = $self->persitence_mangement;
-    $self->detach_all
-        if ($persitence_mangement  && $persitence_mangement eq 'transation');
-}
-
-
-=item rollback
-
-=cut
-
-sub rollback {
-    my ($self) = @_;
-    $self->connection->rollback;
-    my $persitence_mangement = $self->persitence_mangement;
-    $self->detach_all
-        if ($persitence_mangement  && $persitence_mangement eq 'transation');
-}
-
 =item _manage_object
 
 Creates database state of the object in the persistence cache.
@@ -688,33 +868,6 @@ sub _manage_object {
 }
 
 
-=item detach
-
-Removes database object state from cache.
-
-=cut
-
-sub detach {
-    my ($self, $object) = @_;
-    my $persistence_cache = $self->_persistence_cache;
-    my $lazy_fetch_flags = $self->_lazy_fetch_flags;
-    delete $persistence_cache->{$object};
-    delete $lazy_fetch_flags->{$object};
-}
-
-
-=item detach_all
-
-Clears entity cache.
-
-=cut
-
-sub detach_all {
-    my $self = shift;
-    $self->set__persistence_cache({});
-    $self->set__lazy_fetch_flags({});
-}
-
 
 =item add_lazy_fetch_flag
 
@@ -745,19 +898,18 @@ sub has_lazy_fetch_flag {
 }
 
 
-=item connection
-
-Returns connection object.
+=item _reset_lazy_relation_attributes
 
 =cut
 
-sub connection {
-    my ($self) = @_;
-    my $connection = $self->_connection;
-    unless($connection) {
-        $connection = $self->_connection(DBIx::Connection->connection($self->connection_name));
+sub _reset_lazy_relation_attributes {
+    my ($self, $object)  = @_;
+    my $fetch_flags = $self->_lazy_fetch_flags;
+    my $attributes = $fetch_flags->{$object} ||= {};
+    for my $attribute (keys %$attributes) {
+        my $call = "reset_$attribute";
+        $object->$call;
     }
-    $connection;
 }
 
 
